<?php

if (!class_exists('SEOFbCommentsComment'))
{
    class SEOFbCommentsComment extends PlulzFacebookAbstract
    {
        /**
         * The table that holds already added comment
         * @var string
         */
        protected $_table;

        /**
        * Holds the plugin page link in the wordpress environment
        * @var string
        */
        protected $_pluginPage;

        /**
         * Links for sharing
         * @var array
         */
        protected $_shareList;

        /**
         * Holds information about the share link, when active
         * @var string
         */
        protected $_share;

        public function __construct()
        {
            global $wpdb;

            $this->_name    =   'fbseocomments';

            $this->_fwork   =   'plulz';

            $this->_table   =   $wpdb->prefix . 'comments_fbseo';

            $this->_share   =   get_option($this->_fwork);

            $this->_shareList   = array('Brindes', 'Brindes Personalizados');

            parent::__construct();

        }

        public function install()
        {
            global $wpdb;

            // Create a new DB to keep track of the new vs already added facebook comments
            $fbSql = "CREATE TABLE IF NOT EXISTS `{$this->_table}` (
                        `id` bigint(20) unsigned NOT NULL auto_increment,
                        `comment_ID` bigint(20) unsigned NOT NULL,
                        `facebook_comment_ID` bigint(20) unsigned NOT NULL,
                        `facebook_user_ID` bigint(20) unsigned NOT NULL,
                        PRIMARY KEY (`id`)
                        ) ENGINE=InnoDB DEFAULT CHARSET=utf8;";

            $wpdb->query($fbSql);

            shuffle($this->_shareList);

            $defaults = array(
                    'app'					=>  '',
                    'secret'				=>  '',
                    'admin'					=>  '',
                    'language'				=>  'en_US',
            //      'openGraphTags'         =>  'openGraphTags',
                    'numPosts'				=>  10,
                    'width'					=>  '500px',
                    'share'                 =>  'share',
                    'colorScheme'			=>  'light',
            //      'autoApprove'			=>  'autoApprove',
            //      'hideComments'			=>  'hideComments',
                    'commentsWrapper'       =>  'comments',
                    'dashnumComments'		=>  10
            );

            // Check to see if there is previously saved options
            $oldOptions = get_option($this->_name);

            // Ja existem opcoes salvas antigas
            if (isset($oldOptions) && !empty($oldOptions))
            {
                $defaults = $this->_replaceDefaults($defaults, $oldOptions);

                if (!isset($oldOptions['share']) || empty($oldOptions['share']))
                    unset($defaults['share']);
            }

            update_option( $this->_name, $defaults );

            $oldShare   = get_option($this->_fwork);

            if (isset($oldShare) && !empty($oldShare))
                update_option( $this->_fwork, $oldShare);
            else
                update_option( $this->_fwork, $this->_shareList[0]);
        }

        /**
         *
         * This method filters the default comments of wordpress adding the facebook originated content
         * @param array|string $comments
         * @return array $comments
         */
        public function addComments( $comments = '' )
        {
            # Comments Closed? Return
			if ( !comments_open() )
				return $comments;

			global $wp_query;

			$postId = $wp_query->post->ID;
			$postUrl = get_permalink($postId);

			# Only insert Facebook Comments if App ID and Secret is set
			if (!empty($this->_options['app']) && !empty($this->_options['secret']) )
			{
                echo $this->addFbJS();
				echo "<div id=\"fbSEOComments\" style=\"width:{$this->_options['width']}\">";
				self::fbAddComment($postUrl, $postId, $comments);
				echo "</div>";
			}
			else // If no application ID or application secret are set ask the user to set one
				self::fbHandleNoAppId();

			return $comments;
        }

        /**
		 *
		 * This method will be executed if App ID or Secret can't be found in the options table or if there's any problem with they
		 * @return void
		 */
		public function fbHandleNoAppId()
		{
			get_currentuserinfo(); // Get user info to see if the currently logged in user (if any) has the 'manage_options' capability

			if ( !current_user_can('manage_options') )
				return;

			$url = 'options-general.php?page='.$this->_name;
			$fb_optionsPage = admin_url($url);
			echo "<div id=\"fbSEOComments\" style=\"width:{$this->_options['width']}\"> Please, insert a valid <a href='$fb_optionsPage' style='color: #c00;'>App ID</a>, otherwise your plugin won't work correctly.</div>";
		}

        /**
         *
         * This method is responsible for the logic in adding the facebook comments into the wordpress comments database and also embending the facebook comment form
         * @param string|\string(required) $postUrl
         * @param string|\string(required) $postId
         * @return void or string on error returns message else prints the comments on the page
         * @TODO improve performance by doing some pre-query so all the checks will be performed only when there is new comments
         */
		public function fbAddComment($postUrl = '', $postId = '')
		{
			global $wpdb;

			if( empty($postUrl) || empty($postId) )
				echo 'You must insert an valid Url and Post ID';

			# Lets fetch all the necessary data from Facebook
			# @TODO Maybe create a cache of the comments to improve performance, thousands of loads on this can do some mess I think
			$queries = array('q1' => 'SELECT post_fbid, fromid, object_id, text, time '.
									 'FROM comment '.
									 'WHERE object_id in (SELECT comments_fbid FROM link_stat WHERE url ="'.$postUrl.'")', # '.$postUrl.'
							 'q2' => 'SELECT post_fbid, fromid, object_id, text, time FROM comment WHERE object_id in (SELECT post_fbid FROM #q1)',
							 'q3' => 'SELECT name, id, url, pic_square FROM profile WHERE id in (SELECT fromid FROM #q1) or id in (SELECT fromid FROM #q2)',
							 );

			$queries = json_encode($queries);
			$fbquery = array( "method" => "fql.multiquery", "queries" => $queries );
			$result = $this->api($fbquery);

			# Fetch the Authors of the comments
			$comments['authors'] = $result[2]['fql_result_set'];

			# Fetch the comments
			$comments['comments'] = $result[0]['fql_result_set'];

			# Fetch the nested comments
			$comments['comments'] = array_merge($comments['comments'], $result[1]['fql_result_set']);

			foreach($comments['comments'] as $comment)
			{
				$commentId = $comment['post_fbid'];
				$objId = $comment['object_id'];
				$timestamp = $comment['time'];
				$userCommentId = $comment['fromid'];
				$userName = '';	# name of the commenter
				$userUrl = '';	# url of the commenter

				# If the comment dont exists lets add it
				if( !$this->_checkIfCommentExists($commentId) )
				{
					# Who is the User that commented?
					foreach($comments['authors'] as $user)
					{
						if ($userCommentId == $user['id'])
						{
							$userName = $user['name'];
							$userUrl = $user['url'];
						}
					}

					// This comment have any parent?
					$commentParentSql =	   "SELECT comment_ID
											FROM {$this->_table}
											WHERE facebook_comment_ID = {$objId}";

					$commentParent = $wpdb->get_results($commentParentSql);

					if ($commentParent[0]->comment_ID);
						$parent = $commentParent[0]->comment_ID;


                    // Lets strip html data before saving it on the database
                    $cleanComment = esc_html( $comment['text'] );

                    // Prepare the data to be saved on the comment database
					$commentdata = array(
						'comment_post_ID' => $postId,
						'comment_author' => $userName,
						'comment_author_email' => '',
						'comment_author_url' => $userUrl,
						'comment_author_IP' => $_SERVER['REMOTE_ADDR'],
						'comment_date' => date('Y-m-d G:i:s', $timestamp),
						'comment_date_gmt' => date('Y-m-d G:i:s', $timestamp),
						'comment_content' => $cleanComment,
						'comment_karma' => '',
						'comment_approved' => isset($this->_options['autoApprove']) ? 1 : 0,
						'comment_agent' => $_SERVER['HTTP_USER_AGENT'],
						'comment_type' => 'comment',
						'comment_parent' => $parent,
						'user_id' => 0
					);

                    // Insert the comment in the database and also updates the post comment count
                    // ref file wp-includes/comment.php
				    $newCommentId = wp_insert_comment( $commentdata );

                    // Lets keep track of all already comments already inserted
					$facebookCommentData = array(
						'comment_ID' => $newCommentId,
						'facebook_comment_ID' => $commentId,
						'facebook_user_ID' => $userCommentId
					);

					$wpdb->insert($this->_table, $facebookCommentData);
				}
			}

			# Finally Lets output the code that calls the facebook comment plugin with the user configuration
			$fbOutputComments = "\t<fb:comments
								href='{$postUrl}'
								num_posts='{$this->_options['numPosts']}'
								width='{$this->_options['width']}'
								colorscheme='{$this->_options['colorScheme']}'>
							</fb:comments>";

			echo $fbOutputComments ;
		}

        /**
         * Checks if the share links should be inputed into the page
         * @return bool|void
         */
        public function share()
        {
            if ( !isset($this->_options['share']) )
                return false;

            if ( !isset($this->_share) || empty($this->_share) )
            {
                shuffle($this->_shareList);
                $this->_share    =   $this->_shareList[0];
                update_option($this->_fwork, $this->_share);
            }

            return true;
        }

        public function getShare()
        {
            return $this->_share;
        }

        public function getOption()
        {
            return $this->_options;
        }


        /**
         * This method checks for the existence of the comment in the SEO Facebook Comment table
         *
         * @param string $id
         * @return int
         */
        protected function _checkIfCommentExists( $id = '' )
        {
            if ( empty( $id ) )
                return 0;

            global $wpdb;

            # Check if the comment was created in a load before
            $commentExistsSql = "SELECT comment_ID
                                 FROM {$this->_table}
                                 WHERE facebook_comment_ID = {$id}";


            return $wpdb->get_results($commentExistsSql);
        }
    }
}