<?php
/*
 * Plugin Name: SEO Facebook Comments
 * Plugin URI: http://www.plulz.com
 * Description: This plugin will insert a Facebook Comment Form, Open Graph Tags and ALSO insert all Facebook Comments into your Wordpress Database for better SEO.
 * Version: 1.4.2.2
 * Author: Fabio Zaffani
 * Author URI: http://www.plulz.com
 * License: GPL2
 *
 * Copyright 2011  Fabio Alves Zaffani ( email : fabiozaffani@gmail.com )
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License, version 2, as
 * published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */


//$plulz_template_directory =   get_template_directory_uri();
//$plulz_server_directory   =   get_template_directory() . '/';
$plulz_server_directory     =   plugin_dir_path(__FILE__);
$plulz_template_directory =   WP_PLUGIN_URL . '/' . str_replace(basename( __FILE__),"",plugin_basename(__FILE__));

include( $plulz_server_directory .'plulz/lib/Model/PlulzImport.php' );

new PlulzImport($plulz_server_directory);

// Make sure there is no bizarre coincidence of someone creating a class with the exactly same name of this plugin
if ( !class_exists("SEOFacebookComments") )
{
    class SEOFacebookComments extends PlulzAdminControllerAbstract
    {
        protected $_pluginPage;

        protected $_admin;      // Holds current theme main class

        protected $_comments;

        public function __construct()
        {

            $this->_facebook    =   new SEOFbCommentsComment();

            $this->_admin       =   new PlulzAdmin($this->_facebook->getName());

            $this->_options     =   $this->_facebook->getOption();

            $this->_nonce   =   'fbseocomments_nonce';

            register_activation_hook( __FILE__, array( &$this, 'install' ) );
            register_deactivation_hook( __FILE__, array( &$this, 'remove' ) );
            register_uninstall_hook( __FILE__, array( &$this, 'remove' ) );

            parent::__construct();
        }

        public function init()
        {

            $this->_menuPages        =  array(
                0   =>  array(
                   'page_title'    =>  'SEO Facebook Comments',
                   'menu_title'    =>  'SEO Facebook',
                   'capability'    =>  'administrator',
                   'menu_slug'     =>  $this->_facebook->getName(),
                   'icon_url'      =>  $this->_assets . 'img/tiny-logo-plulz.png',
                   'position'      =>  50,
                   'callback'      =>  array(&$this, 'pageMain'),
                   'submenus'      =>  array()
                )
            );

            $this->_pluginPage  =   admin_url('admin.php') . '?page=' . $this->_facebook->getName();

            parent::init();
        }

        public function install()
        {
            $this->_facebook->install();
        }

        public function remove(){}

        /**
         * Default welcome message to be show to the user after plugin installation
         * @return bool
         */
        public function adminMessage()
        {
            if( !empty($this->_options['app']) || !empty($this->_options['secret']) || !empty($this->_options['admin']))
                return false;

            // Check if user has the right privileges to see that warning message
            if ( !current_user_can('administrator') )
                return false;

            $message = '<b>SEO Facebook Comments is almost ready</b>, however you MUST insert the <a href="' . $this->_pluginPage . '"><strong>App ID, App Secret and Admin ID</strong></a>';

            $this->PlulzNotices->addUpdate($this->_name, $message);

            parent::adminMessage();
        }

        public function preLoad(){}

        public function startFrontEnd()
        {
            parent::startFrontEnd();

            // og tags
            if ($this->_options['openGraphTags'])
                $this->setAction( 'wp_head',	array('_facebook', 'addOpenGraph') ); // og tag

            // fbLanguages
            $this->setAction( 'language_attributes', array('_facebook', 'languages') );

             // Add the extra css
            $this->setAction( 'wp_print_styles', 'loadCSS' );

			// comments
			$this->setFilter( 'comments_array',	array( '_facebook', 'addComments' ));

            // share
            if ($this->_facebook->share())
                $this->setAction( 'wp_footer', 'share' );
        }

        /**
         * Extra CSS for especify posts can be added here for example
         * @return void
         */
        public function loadCSS()
        {
            // http://codex.wordpress.org/Function_Reference/wp_register_style
            wp_register_style('SeoFbStylesheet', $this->_assets . 'css/fbseo-style.css');

            // @ref http://codex.wordpress.org/Function_Reference/wp_enqueue_style
            wp_enqueue_style( 'SeoFbStylesheet');

            // Lets check if the user wants to hide the default comments
            if ( isset($this->_options['hideComments']) )
            {
                $wpCommentURL = $this->_assets . 'css/wpcomments.css'; // Respects SSL, fbseo-tyle.css is relative to the file
				wp_register_style('fbSEOwpcomments', $wpCommentURL);
				wp_enqueue_style( 'fbSEOwpcomments');
            }
        }

        public function pageMain()
        {
            $name = PlulzTools::getValue('page', $this->_name);

            $this->set('data', $this->_options );
            $this->set('group' , $name . $this->groupSuffix);
            $this->set('domain', PlulzAdmin::$DOMAIN['www']);
            $this->set('commentOptions', $this->_facebook->getCommentOptions());
            $this->includeTemplate('Main', 'Admin');
        }

        /**
         * Method that inserts a link in the footer if the user allowed it
         * @return bool|void
         */
        public function share()
        {
            $share = $this->_facebook->getShare();

            $output = '<div id="sharefbseo">';
            $output .= 'Plugin from the creators of <a href="http://www.pazzanibrindes.com.br" target="_blank" title="' . $share . '" >' . $share . '</a> :: More at Plulz <a href="http://www.plulz.com" title="Wordpress Plugins" target="_blank">Wordpress Plugins</a>';
            $output .= '</div>';

            echo $output;
        }
    }

    new SEOFacebookComments();
}